# -*- coding: utf-8
from __future__ import unicode_literals, absolute_import

from django.utils.translation import ugettext_lazy as _

STAR_RATING_TYPE = 'star-rating'

RATING_TYPES_CHOICES = (
    (STAR_RATING_TYPE, _("Star")),
)
